@@ -30,6 +30,7 @@ sub DELIVERYSTATUS {
         'status'       => '',   # The value of Status header
         'reason'       => '',   # Temporary reason of bounce
         'command'      => '',   # SMTP command in the message body
+        'replycode',   => '',   # SMTP Reply Code
         'diagnosis'    => '',   # The value of Diagnostic-Code header
         'recipient'    => '',   # The value of Final-Recipient header
         'softbounce'   => '',   # Soft bounce or not
@@ -43,9 +44,9 @@ sub index {
     my $class = shift;
     my $index = [
         'Sendmail', 'Postfix', 'qmail', 'Exim', 'Courier', 'OpenSMTPD', 
-        'Exchange', 'MessagingServer', 'Domino', 'Notes', 'ApacheJames', 
-        'McAfee', 'MXLogic', 'MailFoundry', 'IMailServer', 'mFILTER', 
-        'Activehunter', 'InterScanMSS', 'SurfControl', 'MailMarshalSMTP',
+        'Exchange2007', 'Exchange2003', 'MessagingServer', 'Domino', 'Notes',
+        'ApacheJames', 'McAfee', 'MXLogic', 'MailFoundry', 'IMailServer', 
+        'mFILTER', 'Activehunter', 'InterScanMSS', 'SurfControl', 'MailMarshalSMTP',
         'X1', 'X2', 'X3', 'X4', 'X5', 'V5sendmail', 
     ];
     return $index;
