@@ -110,14 +110,8 @@ sub scan {
                     next unless length $v->{'diagnosis'};
                     next if $e =~ m/\A[-]+/;
 
-                    if( $e =~ m/\AThis has been a permanent failure/ ) {
-                        # This has been a permanent failure.  No further delivery attempts will be made.
-                        $v->{'softbounce'} = 0;
-
-                    } else {
-                        # Server mx22.example.org[192.0.2.222] failed with: 550 <kijitora@example.org> No such user here
-                        $v->{'diagnosis'} .= ' '.$e;
-                    }
+                    # Server mx22.example.org[192.0.2.222] failed with: 550 <kijitora@example.org> No such user here
+                    $v->{'diagnosis'} .= ' '.$e;
                 }
             }
         } # End of if: rfc822
