@@ -226,11 +226,7 @@ sub scan {
             # Giving up on 192.0.2.153.
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\AThis is a permanent error;/ ) {
-                # This is a permanent error; I've given up. Sorry it didn't work out.
-                $v->{'softbounce'} = 0;
-
-            } elsif( $e =~ m/\A(?:To[ ]*:)?[<](.+[@].+)[>]:[ \t]*\z/ ) {
+            if( $e =~ m/\A(?:To[ ]*:)?[<](.+[@].+)[>]:[ \t]*\z/ ) {
                 # <kijitora@example.jp>:
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
